@@ -19,12 +19,11 @@ from typing import Iterator, List, NamedTuple, Tuple
 
 import acme
 from acme.adders import reverb as adders
-from acme.networks import jax as networks
+from acme.jax import networks
+from acme.jax import utils
 from acme.utils import async_utils
 from acme.utils import counting
-from acme.utils import jax_utils
 from acme.utils import loggers
-
 from dm_env import specs
 import haiku as hk
 import jax
@@ -122,9 +121,14 @@ class DQNLearner(acme.Learner, acme.Saveable):
 
       return new_state, outputs
 
+    def update_priorities(outputs: LearnerOutputs):
+      for key, priority in zip(outputs.keys, outputs.priorities):
+        replay_client.mutate_priorities(
+            table=adders.DEFAULT_PRIORITY_TABLE, updates={key: priority})
+
     # Internalise agent components (replay buffer, networks, optimizer).
     self._replay_client = replay_client
-    self._iterator = jax_utils.prefetch(iterator)
+    self._iterator = utils.prefetch(iterator)
 
     # Internalise the hyperparameters.
     self._target_update_period = target_update_period
@@ -135,9 +139,9 @@ class DQNLearner(acme.Learner, acme.Saveable):
 
     # Initialise parameters and optimiser state.
     initial_params = network.init(
-        next(rng), jax_utils.add_batch_dim(jax_utils.zeros_like(obs_spec)))
+        next(rng), utils.add_batch_dim(utils.zeros_like(obs_spec)))
     initial_target_params = network.init(
-        next(rng), jax_utils.add_batch_dim(jax_utils.zeros_like(obs_spec)))
+        next(rng), utils.add_batch_dim(utils.zeros_like(obs_spec)))
     initial_opt_state = optimizer.init(initial_params)
 
     self._state = TrainingState(
@@ -148,6 +152,7 @@ class DQNLearner(acme.Learner, acme.Saveable):
 
     self._forward = jax.jit(network.apply)
     self._sgd_step = jax.jit(sgd_step)
+    self._async_priority_updater = async_utils.AsyncExecutor(update_priorities)
 
   def step(self):
     samples = next(self._iterator)
@@ -164,17 +169,11 @@ class DQNLearner(acme.Learner, acme.Saveable):
 
     # Update priorities in replay.
     if self._replay_client:
-      self._update_priorities(outputs)
+      self._async_priority_updater.put(outputs)
 
     # Write to logs.
     self._logger.write(result)
 
-  @async_utils.make_async
-  def _update_priorities(self, outputs: LearnerOutputs):
-    for key, priority in zip(outputs.keys, outputs.priorities):
-      self._replay_client.mutate_priorities(
-          table=adders.DEFAULT_PRIORITY_TABLE, updates={key: priority})
-
   def get_variables(self, names: List[str]) -> List[hk.Params]:
     return [self._state.params]
 
